summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2020-10-12 14:27:29 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2020-10-13 09:35:20 +0000
commitc30a6232df03e1efbd9f3b226777b07e087a1122 (patch)
treee992f45784689f373bcc38d1b79a239ebe17ee23 /chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h
parent7b5b123ac58f58ffde0f4f6e488bcd09aa4decd3 (diff)
downloadqtwebengine-chromium-85-based.tar.gz
BASELINE: Update Chromium to 85.0.4183.14085-based
Change-Id: Iaa42f4680837c57725b1344f108c0196741f6057 Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
Diffstat (limited to 'chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h')
-rw-r--r--chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h17
1 files changed, 12 insertions, 5 deletions
diff --git a/chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h b/chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h
index 22426dfdec1..b5a8d26fa23 100644
--- a/chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h
+++ b/chromium/third_party/blink/renderer/core/layout/layout_inside_list_marker.h
@@ -6,27 +6,34 @@
#define THIRD_PARTY_BLINK_RENDERER_CORE_LAYOUT_LAYOUT_INSIDE_LIST_MARKER_H_
#include "third_party/blink/renderer/core/core_export.h"
-#include "third_party/blink/renderer/core/layout/layout_list_marker.h"
+#include "third_party/blink/renderer/core/layout/layout_inline.h"
+#include "third_party/blink/renderer/core/layout/list_marker.h"
namespace blink {
// Used to layout the list item's inside marker.
// The LayoutInsideListMarker always has to be a child of a LayoutListItem.
-class CORE_EXPORT LayoutInsideListMarker final : public LayoutListMarker {
+class CORE_EXPORT LayoutInsideListMarker final : public LayoutInline {
public:
explicit LayoutInsideListMarker(Element*);
~LayoutInsideListMarker() override;
const char* GetName() const override { return "LayoutInsideListMarker"; }
+ const ListMarker& Marker() const { return list_marker_; }
+ ListMarker& Marker() { return list_marker_; }
+
private:
bool IsOfType(LayoutObjectType type) const override {
return type == kLayoutObjectInsideListMarker ||
- LayoutListMarker::IsOfType(type);
+ LayoutInline::IsOfType(type);
}
+
+ ListMarker list_marker_;
};
-DEFINE_LAYOUT_OBJECT_TYPE_CASTS(LayoutInsideListMarker, IsInsideListMarker());
+DEFINE_LAYOUT_OBJECT_TYPE_CASTS(LayoutInsideListMarker,
+ IsInsideListMarkerForCustomContent());
} // namespace blink
@@ -6,27 +6,34 @@
namespace blink {
-// Used to layout the list item's inside marker.
+// Used to layout a list item's inside marker with non-normal 'content'.
// The LayoutInsideListMarker always has to be a child of a LayoutListItem.